==> qore-0.9.4.6.tar.bz2: qore-0.9.4.6/docs/modules/TelnetClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TelnetClient Module Reference", "index.html", [
    [ "TelnetClient Module", "index.html", [
      [ "Introduction to the TelnetClient Module", "index.html#telnetclientintro", null ],
      [ "TelnetClient Module Release Notes", "index.html#telnetclient_relnotes", [
        [ "TelnetClient v1.6", "index.html#telnetclient_v1_6", null ],
        [ "TelnetClient v1.5", "index.html#telnetclient_v1_5", null ],
        [ "TelnetClient v1.4", "index.html#telnetclient_v1_4", null ],
        [ "TelnetClient v1.3", "index.html#telnetclient_v1_3", null ],
        [ "TelnetClient v1.2", "index.html#telnetclient_v1_2", null ],
        [ "TelnetClient v1.1", "index.html#telnetclient_v1_1", null ],
        [ "TelnetClient v1.0", "index.html#telnetclient_v1_0", null ],
        [ "TelnetClient v0.9", "index.html#telnetclient_v0_9", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga9d2be4bc7d936dbe4881a6d2b3a45ad0",
"group__file__open__constants.html#ga24d94df00b8914ad6459e39cddfe15bf",
"group__math__functions.html#ga06455c71af5acd6092798bbd73a31d11",
"group__option__constants.html#ga3bc61668e0fc9fd0a3fd172419e94804",
"group__string__functions.html#ga8b90bec06c9dabd6d54fff51684f9da6",
"group__warning__constants.html#gac3e3f433df767225241ac8a79659ac82"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.10.tar.bz2: qore-0.9.10/docs/modules/TelnetClient/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TelnetClient Module Reference", "index.html", [
    [ "TelnetClient Module", "index.html", [
      [ "Introduction to the TelnetClient Module", "index.html#telnetclientintro", null ],
      [ "TelnetClient Module Release Notes", "index.html#telnetclient_relnotes", [
        [ "TelnetClient v1.7", "index.html#telnetclient_v1_7", null ],
        [ "TelnetClient v1.6", "index.html#telnetclient_v1_6", null ],
        [ "TelnetClient v1.5", "index.html#telnetclient_v1_5", null ],
        [ "TelnetClient v1.4", "index.html#telnetclient_v1_4", null ],
        [ "TelnetClient v1.3", "index.html#telnetclient_v1_3", null ],
        [ "TelnetClient v1.2", "index.html#telnetclient_v1_2", null ],
        [ "TelnetClient v1.1", "index.html#telnetclient_v1_1", null ],
        [ "TelnetClient v1.0", "index.html#telnetclient_v1_0", null ],
        [ "TelnetClient v0.9", "index.html#telnetclient_v0_9", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__date__and__time__functions.html#ga9577b42c40fd075fb0bcb5ecabec75a1",
"group__file__open__constants.html#ga5be496ec4bdff357baf0e742139c74b1",
"group__misc__functions.html#ga31f7af53c8c0c95199e6be8d9942440f",
"group__parse__options.html#gad9c582e8e0ece9d44ceeafa778ac12f1",
"group__tattr__local__mode__constants.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
